ed25519_to_x25519_public_key

Function ed25519_to_x25519_public_key 

pub fn ed25519_to_x25519_public_key(
    ed25519_pk: &[u8; 32],
) -> Result<[u8; 32], KeyError>
Convert an Ed25519 public key to an X25519 public key.

This is used when we only have a remote user’s Ed25519 public key (hex string) and need to encrypt something to them via sealed box. The UserKeypair methods handle the local case; this handles the remote case.